@@ -204,39 +204,41 @@ def parse_to_python_object(string):
     return result
 
 def parse_to_CGP_object(python_object):
-    result = ''
-    
     if isinstance(python_object, str):
+        if python_object == '""':
+            return python_object
+                    
         if '"' in python_object:
-            python_object = python_object.replace('"','\"')
-        result += f'"{python_object}"'
-    
-    elif isinstance(python_object, int):
-        result += f'#{str(python_object)}'
+            python_object = python_object.replace('"','\"')            
+        return f'"{python_object}"'
     
     elif isinstance(python_object, dict):
-        result += '{' + ''.join(f'"{str(k)}" = {parse_to_CGP_object(v)};' for k, v in python_object.items()) + '}'
+        return '{' + ''.join(f'{parse_to_CGP_object(k)} = {parse_to_CGP_object(v)};' for k, v in python_object.items()) + '}'
             
     elif isinstance(python_object,list):
-        result += '(' + ''.join(parse_to_CGP_object(x) + ', ' for x in python_object)[:-2] + ')'
+        return '(' + ''.join(parse_to_CGP_object(x) + ', ' for x in python_object)[:-2] + ')'
+    
+    elif isinstance(python_object, int):
+        return f'#{str(python_object)}'
     
     elif isinstance(python_object, datetime):
-        result += datetime.strftime(python_object, '#T%d-%m-%Y_%H:%M:%S')
+        return datetime.strftime(python_object, '#T%d-%m-%Y_%H:%M:%S')
     
     elif isinstance(python_object, IP):
-        result += f'#I[{python_object.ip}]'
+        result = f'#I[{python_object.ip}]'
         try:
             result += f':{python_object.port}'
         except AttributeError:
             pass
+        return result
         
     elif python_object is True:
-        result += "true"
+        return "true"
     
     elif python_object is False:
-        result += "false"
+        return "false"
         
     elif python_object is None:
-        result += "null"
+        return "null"
         
     return result
\ No newline at end of file
